==> coin2_2.3.0.orig.tar.gz: Coin-2.3.0/include/Inventor/VRMLnodes/SoVRMLSubInterpolatorP.h <==
#ifndef COIN_SOVRMLSUBINTERPOLATORP_H
#define COIN_SOVRMLSUBINTERPOLATORP_H

/**************************************************************************\
 *
 *  This file is part of the Coin 3D visualization library.
 *  Copyright (C) 1998-2004 by Systems in Motion.  All rights reserved.
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public License
 *  ("GPL") version 2 as published by the Free Software Foundation.
 *  See the file LICENSE.GPL at the root directory of this source
 *  distribution for additional information about the GNU GPL.
 *
 *  For using Coin with software that can not be combined with the GNU
 *  GPL, and for taking advantage of the additional benefits of our
 *  support services, please contact Systems in Motion about acquiring
 *  a Coin Professional Edition License.
 *
 *  See <URL:http://www.coin3d.org/> for more information.
 *
 *  Systems in Motion, Teknobyen, Abels Gate 5, 7030 Trondheim, NORWAY.
 *  <URL:http://www.sim.no/>.
 *
\**************************************************************************/

#ifndef COIN_INTERNAL
#error this is a private header file
#endif /* !COIN_INTERNAL */
#include <Inventor/nodes/SoSubNodeP.h>

#define SO_INTERPOLATOR_INTERNAL_CONSTRUCTOR(classname) \
  SO_NODE_INTERNAL_CONSTRUCTOR(classname)

#define SO_INTERPOLATOR_INTERNAL_INIT_CLASS(classname) \
  SO_NODE_INTERNAL_INIT_CLASS(classname)

#define SO_INTERPOLATOR_INTERNAL_INIT_ABSTRACT_CLASS(classname) \
  SO_NODE_INTERNAL_INIT_ABSTRACT_CLASS(classname)

#endif // ! COIN_SOVRMLSUBINTERPOLATORP_H

==> coin2_2.4.4.orig.tar.gz: Coin-2.4.4/include/Inventor/VRMLnodes/SoVRMLSubInterpolatorP.h <==
#ifndef COIN_SOVRMLSUBINTERPOLATORP_H
#define COIN_SOVRMLSUBINTERPOLATORP_H

/**************************************************************************\
 *
 *  This file is part of the Coin 3D visualization library.
 *  Copyright (C) 1998-2005 by Systems in Motion.  All rights reserved.
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public License
 *  ("GPL") version 2 as published by the Free Software Foundation.
 *  See the file LICENSE.GPL at the root directory of this source
 *  distribution for additional information about the GNU GPL.
 *
 *  For using Coin with software that can not be combined with the GNU
 *  GPL, and for taking advantage of the additional benefits of our
 *  support services, please contact Systems in Motion about acquiring
 *  a Coin Professional Edition License.
 *
 *  See <URL:http://www.coin3d.org/> for more information.
 *
 *  Systems in Motion, Postboks 1283, Pirsenteret, 7462 Trondheim, NORWAY.
 *  <URL:http://www.sim.no/>.
 *
\**************************************************************************/

#ifndef COIN_INTERNAL
#error this is a private header file
#endif /* !COIN_INTERNAL */
#include <Inventor/nodes/SoSubNodeP.h>

#define SO_INTERPOLATOR_INTERNAL_CONSTRUCTOR(classname) \
  SO_NODE_INTERNAL_CONSTRUCTOR(classname)

#define SO_INTERPOLATOR_INTERNAL_INIT_CLASS(classname) \
  SO_NODE_INTERNAL_INIT_CLASS(classname)

#define SO_INTERPOLATOR_INTERNAL_INIT_ABSTRACT_CLASS(classname) \
  SO_NODE_INTERNAL_INIT_ABSTRACT_CLASS(classname)

#endif // ! COIN_SOVRMLSUBINTERPOLATORP_H
